@@ -1,6 +1,6 @@
 package Perl::Critic::Violation;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -19,8 +19,7 @@ use Perl::Critic::Utils::POD qw<
 >;
 use Perl::Critic::Exception::Fatal::Internal qw< throw_internal >;
 
-our $VERSION = '1.138';
-
+our $VERSION = '1.156';
 
 Readonly::Scalar my $NO_EXCEPTION_NO_SPLIT_LIMIT        => -1;
 Readonly::Scalar my $LOCATION_LINE_NUMBER               => 0;
@@ -31,7 +30,7 @@ Readonly::Scalar my $LOCATION_LOGICAL_FILENAME          => 4;
 
 # Class variables...
 my $format = "%m at line %l, column %c. %e.\n"; # Default stringy format
-my %diagnostics = ();  # Cache of diagnostic messages
+my %diagnostics;
 
 #-----------------------------------------------------------------------------
 
@@ -316,7 +315,7 @@ sub _chomp_periods {
 
     for (@args) {
         next if not defined or ref;
-        s{ [.]+ \z }{}xms
+        s{ [.]+ \z }{}xms;
     }
 
     return @args;
@@ -582,7 +581,7 @@ Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
+Copyright (c) 2005-2023 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
